require "studio_game/game"
require_relative "spec_helper"

module StudioGame
describe Game do 
  
  before do
    @stdout = StringIO.new
  end
  
  before do
    @game = Game.new("Knuckleheads")
   
    @initial_health = 100 
    @player = Player.new("brochacho", @initial_health)
   
    @game.add_player(@player)
  end
  
  it "W00ts the player when a 5 or 6 is rolled" do
    allow_any_instance_of(Die).to receive(:roll).and_return(5)
    
    @game.play(2)
    
    @player.health.should == @initial_health + 15 * 2
  end
  
  it "skips over the player when a medium number is rolled" do
    allow_any_instance_of(Die).to receive(:roll).and_return(3)
    
    @game.play(2)
    
    @player.health.should == @initial_health
  end
  
  it "blams the player when a low number is rolled" do
    allow_any_instance_of(Die).to receive(:roll).and_return(1)
    
    @game.play(2)
    
    @player.health.should == @initial_health - 10 * 2
  end
  
  it "assigns a treasure for points during a player's turn" do
    game = Game.new("Knuckleheads")
    player = Player.new("moe")

    game.add_player(player)

    game.play(1)

    player.points.should_not be_zero
  end
  
  it "computes total points as the sum of all player points" do
    game = Game.new("Knuckleheads")

    player1 = Player.new("moe")
    player2 = Player.new("larry")

    game.add_player(player1)
    game.add_player(player2)

    player1.found_treasure(Treasure.new(:hammer, 50))
    player1.found_treasure(Treasure.new(:hammer, 50))
    player2.found_treasure(Treasure.new(:crowbar, 400))

    game.total_points.should == 500
  end
  
end
end