require "studio_game/player"
require_relative "spec_helper"

module StudioGame
describe Player do
  
  before do
    $stdout = StringIO.new
  end
  
  before do
    @initial_health = 100
    @player = Player.new("moe", @initial_health)
  end
  
  it "has a capitalized name" do
    expect(@player.name).to eq("Moe") #newer syntax from rspec 3
  end
  
  it "has an initial health" do
    @player.health.should == 100 #older rspec syntax from 2.8 (both ways work)
  end
  
  it "has a string representation" do
    @player.found_treasure(Treasure.new(:hammer, 50))
    @player.found_treasure(Treasure.new(:hammer, 50))
    
    @player.to_s.should == "I'm Moe with a health = 100, points = 100, and score = 200."
  end
  
  it "computes a score as the sum of its health and points" do
    @player.found_treasure(Treasure.new(:hammer, 50))
    @player.found_treasure(Treasure.new(:hammer, 50))

    @player.score.should == 200
  end
  
  it "increases health by 15 from w00t" do
    @player.w00t
    @player.health.should == @initial_health + 15 
  end
  
  it "decreases health by 10 from blam" do 
    @player.blam
    
    @player.health.should == @initial_health - 10
  end
  
  context "creating a player with a health of 150" do 
    before do
      @player = Player.new("twochainz", 150)
    end
    it "shows that a character is strong" do
      @player.strong?.should == true
    end
  end
  
  context "creating a player with a health of 100" do 
    before do
      @player = Player.new("twochainz", 100)
    end
    
    it "shows a character is wimpy" do
      @player.strong?.should == false
    end
  end
  
  context "adding players with varying health (which a major component of their score)" do
    before do 
      @player1 = Player.new("moe", 100)
      @player2 = Player.new("larry", 200)
      @player3 = Player.new("curly", 300)
      
      @players = [@player1, @player2, @player3]
    end
    
    it "lists the players from highest to lowest health" do
      @players.sort.should == [@player3, @player2, @player1]
    end
  end
  
  it "computes points as the sum of all treasure points" do
    @player.points.should == 0

    @player.found_treasure(Treasure.new(:hammer, 50))

    @player.points.should == 50

    @player.found_treasure(Treasure.new(:crowbar, 400))

    @player.points.should == 450

    @player.found_treasure(Treasure.new(:hammer, 50))

    @player.points.should == 500
  end
  
  it "yields each found treasure and its total points" do
    @player.found_treasure(Treasure.new(:skillet, 100))
    @player.found_treasure(Treasure.new(:skillet, 100))
    @player.found_treasure(Treasure.new(:hammer, 50))
    @player.found_treasure(Treasure.new(:bottle, 5))
    @player.found_treasure(Treasure.new(:bottle, 5))
    @player.found_treasure(Treasure.new(:bottle, 5))
    @player.found_treasure(Treasure.new(:bottle, 5))
    @player.found_treasure(Treasure.new(:bottle, 5))

    yielded = []
    @player.each_treasure do |treasure|
      yielded << treasure
    end

    yielded.should == [
      Treasure.new(:skillet, 200),
      Treasure.new(:hammer, 50),
      Treasure.new(:bottle, 25)
   ]
  end
  
  it "can be created from a CSV string" do
    player = Player.from_csv("larry,150")

    player.name.should == "Larry"
    player.health.should == 150
  end
  
end
end